@@ -1,6 +1,6 @@
 package App::GitGot::Command;
 {
-  $App::GitGot::Command::VERSION = '1.08';
+  $App::GitGot::Command::VERSION = '1.09';
 }
 BEGIN {
   $App::GitGot::Command::AUTHORITY = 'cpan:GENEHACK';
@@ -78,6 +78,14 @@ has 'tags' => (
   traits        => [qw/ Getopt /],
 );
 
+has 'skip_tags' => (
+  is            => 'rw',
+  isa           => 'ArrayRef[Str]',
+  documentation => 'select repositories not tagged with these words' ,
+  cmd_aliases   => 'T',
+  traits        => [qw/ Getopt /],
+);
+
 has 'verbose' => (
   is            => 'rw',
   isa           => 'Bool',
@@ -176,7 +184,7 @@ sub _build_active_repo_list {
   my ( $self ) = @_;
 
   return $self->full_repo_list
-    if $self->all or ! $self->tags and ! @{ $self->args };
+    if $self->all or ! $self->tags and ! $self->skip_tags and ! @{ $self->args };
 
   my $list = _expand_arg_list( $self->args );
 
@@ -187,6 +195,12 @@ sub _build_active_repo_list {
       next REPO;
     }
 
+    if ( $self->skip_tags ) {
+      foreach my $tag ( @{ $self->skip_tags } ) {
+        next REPO if grep { $repo->tags =~ /\b$_\b/ } $tag;
+      }
+    }
+
     if ( $self->tags ) {
       foreach my $tag ( @{ $self->tags } ) {
         if ( grep { $repo->tags =~ /\b$_\b/ } $tag ) {
@@ -195,6 +209,7 @@ sub _build_active_repo_list {
         }
       }
     }
+    push @repos, $repo unless $self->tags or @$list;
   }
 
   return \@repos;
@@ -457,7 +472,7 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 METHODS
 
